Cosmpy is a Python library for interacting with Cosmos-based blockchains.

* A simplified command line tool for querying and sending transactions to Cosmos-SDK blockchains. 
* Features an easy interface for deploying and interacting with Cosmwasm smart contracts.
* Provides access to lower-level ledger APIs for advanced use-cases. 

## To install

``` bash
pip3 install cosmpy
```

## Version

<a href="https://img.shields.io/pypi/v/cosmpy" target="_blank"><img alt="PyPI" src="https://img.shields.io/pypi/v/cosmpy" /></a>.

## Repository

```
https://github.com/fetchai/cosmpy
```

## To contribute

Clone the repo:

``` bash
git clone https://github.com/fetchai/cosmpy.git --recursive && cd cosmpy
```

Set up development environment:

``` bash
make new_env_dev
```

This creates a new `pipenv` virtual environment and installs the development dependencies.

Enter the virtual environment: 

``` bash
pipenv shell
```
     
